using System;
using System.Collections;
using Server.Misc;
using Server.Items;
using Server.Targeting;

namespace Server.Mobiles
{
	[CorpseName( "a ratman corpse" )]
	public class ClanChitterTinkerer : BaseCreature
	{
		public override InhumanSpeech SpeechType{ get{ return InhumanSpeech.Ratman; } }

		[Constructable]
		public ClanChitterTinkerer() : base( AIType.AI_Archer, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "Clan Chitter Tinkerer";
			Body = 0x8E;
			BaseSoundID = 437;

			SetStr( 303, 328 );
			SetDex( 222, 238 );
			SetInt( 242, 271 );

			SetHits( 2027, 2068 );

			SetDamage( 8, 10 );

			SetDamageType( ResistanceType.Physical, 100 );

			SetResistance( ResistanceType.Physical, 23, 29 );
			SetResistance( ResistanceType.Fire, 22, 30 );
			SetResistance( ResistanceType.Cold, 37, 48 );
			SetResistance( ResistanceType.Poison, 10, 18 );
			SetResistance( ResistanceType.Energy, 14, 20 );

			SetSkill( SkillName.Anatomy, 60.2, 100.0 );
			SetSkill( SkillName.Archery, 80.1, 90.0 );
			SetSkill( SkillName.MagicResist, 81.0, 89.2 );
			SetSkill( SkillName.Tactics, 53.8, 74.5 );
			SetSkill( SkillName.Wrestling, 72.3, 74.5 );

			Fame = 6500;
			Karma = -6500;

			VirtualArmor = 56;
		}

		public override void GenerateLoot()
		{
			AddLoot( LootPack.Rich );
		}

		public override bool CanRummageCorpses{ get{ return true; } }
		public override int Hides{ get{ return 8; } }
		public override HideType HideType{ get{ return HideType.Spined; } }

		public ClanChitterTinkerer( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();

			if ( Body == 42 )
			{
				Body = 0x8E;
				Hue = 0;
			}
		}
	}
}
