using System;
using System.Collections;
using Server.Misc;
using Server.Items;
using Server.Targeting;

namespace Server.Mobiles
{
	[CorpseName( "a ratman corpse" )]
	public class ClanScratchHenchrat : BaseCreature
	{
		public override InhumanSpeech SpeechType{ get{ return InhumanSpeech.Ratman; } }

		[Constructable]
		public ClanScratchHenchrat() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "Clan Scratch Henchrat";
			Body = 0x8F;
			BaseSoundID = 437;

			SetStr( 227 );
			SetDex( 183 );
			SetInt( 93 );

			SetHits( 2065 );

			SetDamage( 5, 7 );

			SetDamageType( ResistanceType.Physical, 100 );

			SetResistance( ResistanceType.Physical, 26 );
			SetResistance( ResistanceType.Fire, 29 );
			SetResistance( ResistanceType.Cold, 32 );
			SetResistance( ResistanceType.Poison, 17 );
			SetResistance( ResistanceType.Energy, 13 );
			
			SetSkill( SkillName.MagicResist, 35.4 );
			SetSkill( SkillName.Tactics, 61.1 );
			SetSkill( SkillName.Wrestling, 64,2 );

			Fame = 7500;
			Karma = -7500;

			VirtualArmor = 44;

			PackReg( 6 );

			if ( 0.02 > Utility.RandomDouble() )
				PackStatue();
		}

		public override void GenerateLoot()
		{
			AddLoot( LootPack.Rich );
			AddLoot( LootPack.LowScrolls );
		}

		public override bool CanRummageCorpses{ get{ return true; } }
		public override int Meat{ get{ return 1; } }
		public override int Hides{ get{ return 8; } }
		public override HideType HideType{ get{ return HideType.Spined; } }

		public ClanScratchHenchrat( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();

			if ( Body == 42 )
			{
				Body = 0x8F;
				Hue = 0;
			}
		}
	}
}
